OC.L10N.register(
    "files_trashbin",
    {
    "Couldn't delete %s permanently" : "No se puede eliminar %s permanentemente",
    "Couldn't restore %s" : "No se puede restaurar %s",
    "Deleted files" : "Archivos eliminados",
    "Restore" : "Recuperar",
    "Delete" : "Eliminar",
    "Delete permanently" : "Eliminar permanentemente",
    "Error" : "Error",
    "restored" : "recuperado",
    "Name" : "Nombre",
    "Deleted" : "Eliminado"
},
"nplurals=2; plural=(n != 1);");
